@@ -90,6 +90,7 @@ class BaseTestCollectdPlugin(unittest.TestCase):
         port = collectd.Config('Port', ('15672',))
         schema = collectd.Config('Scheme', ('http',))
         vhost_prefix = collectd.Config('VHostPrefix', ('',))
+        validate_certs = collectd.Config('ValidateCerts', ('false',))
 
         ignore_queues = [
             collectd.Config('Regex', ('amq-gen-.*',)),
@@ -109,7 +110,8 @@ class BaseTestCollectdPlugin(unittest.TestCase):
                        schema,
                        ignore_queue,
                        ignore_exchange,
-                       vhost_prefix
+                       vhost_prefix,
+                       validate_certs
                        ]
         self.test_config = collectd.Config(
             'Module', ('rabbitmq',), config_data)
@@ -289,6 +291,24 @@ class TestCollectdPluginQueues(BaseTestCollectdPlugin):
 
         self.assertTrue(mock_dispatch.called)
 
+    @patch.object(collectd_plugin.rabbit.RabbitMQStats, 'get_vhosts')
+    @patch('collectd_rabbitmq.rabbit.urllib2.urlopen')
+    def test_dispatch_queue_stats_consumer_utilisation(
+      self, mock_urlopen, mock_vhosts):
+        """
+        Assert queues are dispatched with preoper data.
+        Args:
+        :param mock_urlopen: a patched :mod:`rabbit.urllib2.urlopen` object
+        :param mock_vhosts: a patched method from a :mod:`CollectdPlugin`
+        """
+        mock_dispatch = MagicMock()
+        mock_queue_stats = dict(consumer_utilisation=None)
+        self.collectd_plugin.dispatch_values = mock_dispatch
+        self.collectd_plugin.dispatch_queue_stats(
+            mock_queue_stats, 'test_vhost', None, None)
+
+        self.assertTrue(mock_dispatch.called)
+
     @patch.object(collectd_plugin.rabbit.RabbitMQStats, 'get_vhosts')
     @patch('collectd_rabbitmq.rabbit.urllib2.urlopen')
     def test_dispatch_empty_queue_stats(self, mock_urlopen, mock_vhosts):
